@@ -433,7 +433,7 @@ class Session(object):
                     ]
 
             其中，instance-name按照名称过滤，search-by-name按照名称检索，模糊匹配，
-                status按照状态来检索，状态值包括Completed、Failed、MaxRuntimeExceeded、Stopped、Training
+                status按照状态来检索，状态值包括Completed、Failed、、Stopped、InProgress
 
             offset: (str), 表示偏移量
 
@@ -501,7 +501,7 @@ class Session(object):
             job_name: (str), 表示训练任务名称
 
             metric_name: (str)，表示训练任务的监控指标名称，取值为CpuCoreUsed、CpuCoreUsedRate、MemUsage、
-                        GpuMemUsageRate、GpuCoreUsed、GpuCoreUsedRate
+                        MemUsageRate、GpuCoreUsed、GpuCoreUsedRate
 
             start_time: (str)，表示起始时间，如2020-05-22 17:51:00
 
